AddressFactory class abstract interface

Factory interface for creating and parsing Address instances.

Provides methods to parse existing addresses from their string representation.

Implementers

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseAddress(String address) → Address?
Parses a string representation into an Address instance.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited