CryptoExtensions class final

Singleton extension class for cryptographic key operations.

Centralizes access to crypto helpers (symmetric/private/public key helpers) using Dart extensions for clean, modular access.

Available extensions

Constructors

CryptoExtensions()
factory

Properties

handler ↔ CryptoKeyHandler?

Available on CryptoExtensions, provided by the GeneralCryptoExtension extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
privateHelper ↔ PrivateKeyHelper?

Available on CryptoExtensions, provided by the PrivateKeyExtension extension

Get the private key helper (null before set).
getter/setter pair
publicHelper ↔ PublicKeyHelper?

Available on CryptoExtensions, provided by the PublicKeyExtension extension

Get the public key helper (null before set).
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
symmetricHelper ↔ SymmetricKeyHelper?

Available on CryptoExtensions, provided by the SymmetricKeyExtension extension

Get the symmetric key helper (null before set).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited