GeneralDocumentFactory class

General Document Factory

Implemented types

Constructors

GeneralDocumentFactory(String type)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
final

Methods

createDocument({String? data, TransportableData? signature}) Document
Creates a Document instance from data and signature.
override
createEmptyDocument() Document
createValidDocument(String data, TransportableData signature) Document
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseDocument(Mapping doc) Document?
Parses a serialized Map into a Document instance.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited