Base58 class final

Base58 encoding utility (facade for DataCoder).

Converts binary data to/from Base58 string representation (Bitcoin-style alphabet without '0', 'O', 'I', 'l').

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

coder DataCoder?
The DataCoder implementation (null before set).
getter/setter pair

Static Methods

decode(String string) Uint8List?
Decodes a Base58 string back to binary data.
encode(Uint8List data) String
Encodes binary data to a Base58 string.