isValid property

  1. @override
bool get isValid
override

Validates the integrity of this TAI data.

Returns true if the signature matches the data and entity's public key, false if signature is missing or invalid.

Implementation

@override
bool get isValid => _status > 0;