Comparator class final

Data Compare Utilities

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

comparator DataComparator
getter/setter pair

Static Methods

different(dynamic a, dynamic b) bool
Check whether the two objects are different (deep compare).
identical(dynamic a, dynamic b) bool
Check whether the two objects are the same instance (null-aware).
listEquals<T>(List<T>? a, List<T>? b) bool
Check whether the two lists are equal (element-wise).
mapEquals<K, V>(Map<K, V>? a, Map<K, V>? b) bool
Check whether the two maps are equal (element-wise).