identical static method
Check whether the two objects are the same instance (null-aware).
Implementation
static bool identical(dynamic a, dynamic b) =>
comparator.identical(a, b);
Check whether the two objects are the same instance (null-aware).
static bool identical(dynamic a, dynamic b) =>
comparator.identical(a, b);