Copier class final
Data Copy Utilities
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- copier ↔ DataCopier
-
getter/setter pair
Static Methods
-
copy(
Object? object) → dynamic - Shallow copy any object.
-
copyList<
T> (List array) → List< T> - Shallow copy the list.
-
copyMap<
K, V> (Mapping dict) → Map< K, V> - Shallow copy the map.
-
deepCopy(
Object? object) → dynamic - Deep copy any object.
-
deepCopyList<
T> (List array) → List< T> - Deep copy the list.
-
deepCopyMap<
K, V> (Mapping dict) → Map< K, V> - Deep copy the map.