group property

ID? get group

Optional group identifier for group messages.

Special Behavior: When a group message is split into individual messages for group members, the receiver field is updated to the member's ID, and the original group ID is stored in this group field to preserve context.

Returns the original group ID for split group messages, null for direct messages.

Implementation

ID? get group;
set group (ID? gid)

Set the group ID for a split group message.

gid is the original group ID (null for direct messages).

Implementation

set group(ID? gid);