JSON class final

JSON encoding utility (facade for ObjectCoder).

Converts structured objects (Map/List) to/from JSON strings.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

coder ObjectCoder?
The ObjectCoder implementation (null before set).
getter/setter pair

Static Methods

decode(String json) → dynamic
Decodes a JSON string back to a structured object.
encode(Object container) String
Encodes a structured object to a JSON string.