KECCAK256 class final
Keccak-256 hash utility (facade for MessageDigester).
Computes the Keccak-256 message digest (32-byte / 256-bit hash value).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- digester ↔ MessageDigester?
-
The MessageDigester implementation (null before set).
getter/setter pair