decode method
Decodes a serialized string back to a structured object.
string is the serialized string to deserialize.
Returns the deserialized object of type T, or null if decoding fails.
Implementation
@override
Mapping? decode(String string) {
return JSON.coder!.decode(string);
}