group property

  1. @override
ID? get group
override

Optional group identifier for group messages.

Special Behavior: When a group message is split into individual messages for group members, the receiver field is updated to the member's ID, and the original group ID is stored in this group field to preserve context.

Returns the original group ID for split group messages, null for direct messages.

Implementation

@override
ID? get group => ID.parse(this['group']);
  1. @override
set group (ID? gid)
override

Set the group ID for a split group message.

gid is the original group ID (null for direct messages).

Implementation

@override
set group(ID? gid) => setString('group', gid);