isBroadcast abstract method

bool isBroadcast(
  1. Message message
)

Checks whether this is a broadcast message.

  1. If receiver is broadcast, return true
  2. If group exists and is broadcast, return true too

message is the message with sender and optional group.

Returns true if the message is a broadcast.

Implementation

bool isBroadcast(Message message);