parseMeta abstract method

Meta? parseMeta(
  1. Mapping meta
)

Parses a serialized Map into a Meta instance.

meta is the serialized metadata in the Map format defined in Meta.

Returns a Meta instance if parsing succeeds, null otherwise.

Implementation

Meta? parseMeta(Mapping meta);