decode abstract method

T? decode(
  1. String string
)

Decodes a serialized string back to a structured object.

string is the serialized string to deserialize.

Returns the deserialized object of type T, or null if decoding fails.

Implementation

T? decode(String string);