PortableNetworkFile class

Inheritance
Implemented types

Constructors

PortableNetworkFile(Mapping? content, {TransportableData? data, String? filename, Uri? url, DecryptKey? password, TransportableFileWrapper? wrapper})
PortableNetworkFile.createWithData(TransportableData data, String? filename)
factory
PortableNetworkFile.createWithURL(Uri url, DecryptKey? password)
factory
PortableNetworkFile.from(TransportableData? data, String? filename, Uri? url, DecryptKey? password)

Properties

data TransportableData?
file data
getter/setter pairoverride
entries Iterable<MapEntry<String, dynamic>>
The map entries of this Map.
no setterinherited
filename String?
file name
getter/setter pairoverride
hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
Whether there is no key/value pair in the map.
no setterinherited
isNotEmpty bool
Whether there is at least one key/value pair in the map.
no setterinherited
keys Iterable<String>
The keys of this Map.
no setterinherited
length int
The number of key/value pairs in the map.
no setterinherited
password DecryptKey?
decrypt key
getter/setter pairoverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uriString String
no setter
url Uri?
download URL
getter/setter pairoverride
values Iterable
The values of this Map.
no setterinherited

Methods

addAll(Map other) → void
Adds all key/value pairs of other to this map.
inherited
addEntries(Iterable<MapEntry> newEntries) → void
Adds all key/value pairs of newEntries to this map.
inherited
cast<RK, RV>() Map<RK, RV>
Map<String, dynamic>
inherited
clear() → void
Removes all entries from the map.
inherited
containsKey(Object? key) bool
Whether this map contains the given key.
inherited
containsValue(Object? value) bool
Whether this map contains the given value.
inherited
copyMap([bool deepCopy = false]) Map<String, dynamic>
Copy inner map.
inherited
forEach(void action(String key, dynamic value)) → void
Applies action to each key/value pair of the map.
inherited
getBool(dynamic key, [bool? defaultValue]) bool?
inherited
getDateTime(dynamic key, [DateTime? defaultValue]) DateTime?
inherited
getDouble(dynamic key, [double? defaultValue]) double?
inherited
getInt(dynamic key, [int? defaultValue]) int?
inherited
getString(dynamic key, [String? defaultValue]) String?
Get string value for key, if value is None, return the default value.
inherited
map<K2, V2>(MapEntry<K2, V2> convert(String key, dynamic value)) Map<K2, V2>
Returns a new map where all entries of this map are transformed by the given convert function.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putIfAbsent(dynamic key, dynamic ifAbsent()) → dynamic
Look up the value of key, or add a new entry if it isn't there.
inherited
remove(Object? key) → dynamic
Removes key and its associated value, if present, from the map.
inherited
removeWhere(bool test(String key, dynamic value)) → void
Removes all entries of this map that satisfy the given test.
inherited
serialize() Object
Serializes the PNF to a transportable format.
override
setDateTime(dynamic key, DateTime? time) → void
inherited
setMap(dynamic key, Mapper? mapper) → void
inherited
setString(dynamic key, Stringer? stringer) → void
inherited
toMap() MutableMapping
Get inner map.
override
toString() String
A string representation of this object.
override
update(dynamic key, dynamic update(dynamic value), {dynamic ifAbsent()?}) → dynamic
Updates the value for the provided key.
inherited
updateAll(dynamic update(String key, dynamic value)) → void
Updates all values.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](Object? key) → dynamic
The value for the given key, or null if key is not in the map.
inherited
operator []=(dynamic key, dynamic value) → void
Associates the key with the given value.
inherited