generatePrivateKey abstract method

PrivateKey? generatePrivateKey(
  1. String algorithm
)

Generate a new private key for the specified algorithm.

Creates a cryptographically secure random private key for the given algorithm.

Returns null if the algorithm is unsupported.

Implementation

PrivateKey? generatePrivateKey(String algorithm);