PublicKeyHelper class abstract interface

Helper interface for public key management.

Manages public key factories (by algorithm) and provides methods to parse raw public key data into PublicKey instances.

Public keys are used for verifying signatures or encrypting data for a specific recipient.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPublicKeyFactory(String algorithm) PublicKeyFactory?
Get public key factory for the specified algorithm.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parsePublicKey(Object? key) PublicKey?
Parse raw public key data into a PublicKey instance.
setPublicKeyFactory(String algorithm, PublicKeyFactory factory) → void
Set public key factory for the specified algorithm.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited