create static method

ReliableMessage create(
  1. SecureMessage sMsg,
  2. Uint8List signature
)
override

Create a ReliableMessage from a secure message, adding 'signature'.

Signs the encrypted content data with the sender's private key, forming the digital signature for authenticity and integrity verification.

sMsg is the encrypted secure message. signature is the signature of the encrypted content data.

Returns a new ReliableMessage instance.

Implementation

static ReliableMessage create(SecureMessage sMsg, Uint8List signature) {
  final helper = sharedMessageExtensions.reliableHelper;
  return helper!.createReliableMessage(sMsg, signature);
}