Interface for encrypted secure messages (second stage).
Represents an InstantMessage that has been encrypted with a symmetric key, providing confidentiality for the message content. The original plaintext content is replaced with encrypted data and encrypted keys for decryption.
Serialized format (Map/JSON):
{
// Envelope metadata (unchanged from InstantMessage)
"sender" : "moki@xxx", // Sender's unique ID
"receiver" : "hulk@yyy", // Receiver's unique ID
"time" : 123.45, // Message timestamp (Unix timestamp in seconds)
// Encrypted content data and keys
"data" : "...", // base64_encode( symmetric_encrypt(content))
"keys" : {
"{ReceiverID}" : "...", // base64_encode(asymmetric_encrypt(pwd))
"digest" : "..." // hash(pwd.data)
}
}
- Implemented types
- Implementers
Properties
- data → TransportableData
-
Encrypted message content (Base64-encoded).
no setter
- encryptedKeys → Map?
-
Map of encrypted symmetric keys (recipient ID → encrypted key string).
no setter
-
entries
→ Iterable<
MapEntry< String, dynamic> > -
The map entries of this Map.
no setterinherited
- envelope → Envelope
-
Complete message envelope containing routing metadata.
no setterinherited
- group → ID?
-
Returns the group ID for group messages (content.group or envelope.group).
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEmpty → bool
-
Whether there is no key/value pair in the map.
no setterinherited
- isNotEmpty → bool
-
Whether there is at least one key/value pair in the map.
no setterinherited
-
keys
→ Iterable<
String> -
The keys of this Map.
no setterinherited
- length → int
-
The number of key/value pairs in the map.
no setterinherited
- receiver → ID
-
Returns the message receiver ID (envelope.receiver).
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sender → ID
-
Returns the message sender ID (envelope.sender).
no setterinherited
- time → DateTime?
-
Returns the message timestamp (content.time or envelope.time).
no setterinherited
- type → String?
-
Returns the message type (content.type or envelope.type).
no setterinherited
- values → Iterable
-
The values of this Map.
no setterinherited
Methods
-
addAll(
Map< String, dynamic> other) → void -
Adds all key/value pairs of
otherto this map.inherited -
addEntries(
Iterable< MapEntry< newEntries) → voidString, dynamic> > -
Adds all key/value pairs of
newEntriesto this map.inherited -
cast<
RK, RV> () → Map< RK, RV> -
Provides a view of this map as having
RKkeys andRVinstances, if necessary.inherited -
clear(
) → void -
Removes all entries from the map.
inherited
-
containsKey(
Object? key) → bool -
Whether this map contains the given
key.inherited -
containsValue(
Object? value) → bool -
Whether this map contains the given
value.inherited -
copyMap(
[bool deepCopy = false]) → Map< String, dynamic> -
Copy inner map.
inherited
-
forEach(
void action(String key, dynamic value)) → void -
Applies
actionto each key/value pair of the map.inherited -
getBool(
String key, [bool? defaultValue]) → bool? -
inherited
-
getDateTime(
String key, [DateTime? defaultValue]) → DateTime? -
inherited
-
getDouble(
String key, [double? defaultValue]) → double? -
inherited
-
getInt(
String key, [int? defaultValue]) → int? -
inherited
-
getString(
String key, [String? defaultValue]) → String? -
Get string value for key, if value is None, return the default value.
inherited
-
map<
K2, V2> (MapEntry< K2, V2> convert(String key, dynamic value)) → Map<K2, V2> -
Returns a new map where all entries of this map are transformed by
the given
convertfunction.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
putIfAbsent(
String key, dynamic ifAbsent()) → dynamic -
Look up the value of
key, or add a new entry if it isn't there.inherited -
remove(
Object? key) → dynamic -
Removes
keyand its associated value, if present, from the map.inherited -
removeWhere(
bool test(String key, dynamic value)) → void -
Removes all entries of this map that satisfy the given
test.inherited -
setDateTime(
String key, DateTime? time) → void -
inherited
-
setMap(
String key, Mapper? mapper) → void -
inherited
-
setString(
String key, Stringer? stringer) → void -
inherited
-
toMap(
) → MutableMapping -
Get inner map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
String key, dynamic update(dynamic value), {dynamic ifAbsent()?}) → dynamic -
Updates the value for the provided
key.inherited -
updateAll(
dynamic update(String key, dynamic value)) → void -
Updates all values.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
Object? key) → dynamic -
The value for the given
key, ornullifkeyis not in the map.inherited -
operator []=(
String key, dynamic value) → void -
Associates the
keywith the givenvalue.inherited
Static Methods
-
create(
InstantMessage iMsg, Uint8List ciphertext, Map< ID, EncryptedBundle> ? keyBundles) → SecureMessage - Create a SecureMessage from an instant message, adding 'data' and 'keys'.
-
getFactory(
) → SecureMessageFactory? - Get the secure message factory.
-
parse(
Object? msg) → SecureMessage? - Parse a raw object into a SecureMessage instance.
-
setFactory(
SecureMessageFactory factory) → void - Register the secure message factory.