decode abstract method

String? decode(
  1. Uint8List data
)

Decodes binary data back to a string using the specified character encoding.

data is the binary data to decode.

Returns the decoded string, or null if decoding fails.

Implementation

String? decode(Uint8List data);