encode abstract method

Uint8List encode(
  1. String string
)

Encodes a string to binary data using the specified character encoding.

string is the string to encode.

Returns the binary representation of the string as Uint8List.

Implementation

Uint8List encode(String string);