getProperty abstract method
Retrieves a specific property value by name.
name is the name of the property to retrieve.
Returns the value of the property (may be null if property doesn't exist).
Implementation
dynamic getProperty(String name);
Retrieves a specific property value by name.
name is the name of the property to retrieve.
Returns the value of the property (may be null if property doesn't exist).
dynamic getProperty(String name);