setProperty abstract method

void setProperty(
  1. String name,
  2. Object? value
)

Updates or adds a property (resets signature).

Modifying properties invalidates the existing signature (both isValid and the stored signature will be reset). A new signature must be generated with sign() after making changes.

name is the name of the property to update/add. value is the new value for the property (may be null to remove).

Implementation

void setProperty(String name, Object? value);