TransportableDataHelper class abstract interface

Helper interface for processing TransportableData (TED) objects.

Provides core functionality for managing TransportableData factories and parsing raw data objects into strongly-typed TransportableData instances.

TransportableData is used to encapsulate serializable binary/data content in message payloads.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createTransportableData(Uint8List data, {String? encoding, String? mimeType, Mapping<String, String>? parameters}) TransportableData
Create a TransportableData instance from raw data.
getTransportableDataFactory() TransportableDataFactory?
Get the TransportableData factory.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseTransportableData(Object? ted) TransportableData?
Parse a raw object into a TransportableData instance.
setTransportableDataFactory(TransportableDataFactory factory) → void
Set the TransportableData factory.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited