UTF8 class final

UTF-8 encoding utility (facade for StringCoder).

Converts strings to/from UTF-8 encoded binary data.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

coder StringCoder?
The StringCoder implementation (null before set).
getter/setter pair

Static Methods

decode(Uint8List utf8) String?
Decodes UTF-8 binary data back to a string.
encode(String string) Uint8List
Encodes a string to UTF-8 binary data.