Wrapper class final

Data Wrap Utilities

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

wrapper DataWrapper
getter/setter pair

Static Methods

getMap(Object? dict) Map?
Shallow unwrap dict value.
getString(Object? str) String?
Shallow unwrap string value.
unwrap(Object? object) → dynamic
Deep unwrap value.
unwrapList<T>(List array) List<T>
Deep unwrap List value.
unwrapMap<K, V>(Mapping dict) Map<K, V>
Deep unwrap dict value.