dimax library
DIM-AX
DIM Application eXtensions
Classes
- AccountExtensions
- Singleton extension class for account system operations.
- AccountHandler
- General account handler interface for common account system utilities.
- Address
- Interface for network addresses used to identify MKM ID entities.
- AddressFactory
- Factory interface for creating and parsing Address instances.
- AddressHelper
- Helper interface for address management in the account system.
- ArrayContent
- Content array interface for sending multiple contents in one message.
- AsymmetricKey
- Base interface for asymmetric cryptographic keys (public/private key pairs).
- AudioContent
- Audio message content interface.
- AudioFileContent
- BaseAddressFactory
- Base address factory.
- BaseBulletin
- Base Document for Group
- BaseDocument
- Base document.
- BaseDocumentCommand
- BaseFileContent
- BaseGroupCommand
- BaseHistoryCommand
- BaseMeta
- User/Group Meta data This class is used to generate entity meta.
- BaseMetaCommand
- BaseMetaFactory
- Base meta factory.
- BaseMoneyContent
- BaseQuoteContent
- BaseReceiptCommand
- BaseTextContent
- BaseVisa
- Base Document for User
- BTCAddress
- Address like BitCoin.
- BTCMeta
- Meta to build BTC address for ID
- Bulletin
- Group Bulletin document interface (group-specific announcement document).
- CombineContent
- Combined forward content for chat history forwarding.
- CombineForwardContent
- Command
- Command message content interface.
- CommandFactory
- Factory interface for parsing command messages from map objects.
- CommandHandler
- A helper interface for extracting command names from structured command content.
- CommandHelper
- General Helper
- CommandParser
- Command factory that builds command from a raw map.
- Content
- Interface for message content (body) that contains the actual message data.
- ContentFactory
- Factory interface for parsing Content instances from serialized data.
- ContentHelper
- Helper interface for message content management.
- ContentParser
- Content factory that builds content from a raw map.
- ContentType
- A flag to indicate what kind of message content this is.
- CryptoExtensions
- Singleton extension class for cryptographic key operations.
- CryptographyKey
- Base interface for cryptographic keys with algorithm identification.
- CryptoKeyHandler
- General cryptographic handler interface for key validation and algorithm handling.
- DecryptKey
- Interface for decryption keys (symmetric or asymmetric private keys).
- DefaultBundleHandler
- DefaultMeta
- Default Meta to build ID with 'name@address'
- Document
- Interface for entity profile documents (extends TAI with structured data).
- DocumentCommand
- Document command interface for querying/updating entity documents.
- DocumentFactory
- Factory interface for creating and parsing Document instances.
- DocumentHelper
- Helper interface for document management in the account system.
- DocumentType
- Document types.
- EncryptedBundleHandler
- EncryptKey
- Interface for encryption keys (symmetric or asymmetric public keys).
- EntityType
- A network ID to indicate what kind the entity is.
- Envelope
- Interface for message envelopes (headers) that contain routing/metadata for messages.
- EnvelopeFactory
- Factory interface for creating and parsing Envelope instances.
- EnvelopeHelper
- Helper interface for message envelope management.
- ETHAddress
- Address like Ethereum.
- ETHMeta
- Meta to build ETH address for ID
- ExpelCommand
- Group expel command interface (DEPRECATED).
- ExpelGroupCommand
- ExpelCommand (Deprecated, use 'reset' instead)
- ExtensionLoader
- Core extensions loader.
- FileContent
- File message content interface.
- FormatExtensions
- Singleton extension class for message format operations.
- ForwardContent
- Top-secret forward content. Wraps secure and certified messages.
- GeneralAccountHelper
- General account helper.
- GeneralCommandFactory
- General Command Factory
- GeneralCommandHelper
- General command helper.
- GeneralDocumentFactory
- General document factory.
- GeneralMessageHelper
- General message helper.
- GroupCommand
- Group command interface for tracking group member/role changes.
- GroupCommandFactory
- Group command factory.
- HistoryCommand
- History command interface for recording operational history.
- HistoryCommandFactory
- History command factory.
- ID
- Interface for unique identifiers (ID) of network entities (users/groups).
- Identifier
- Concrete implementation of ID (wraps a constant string).
- IdentifierFactory
- General ID factory.
- IDFactory
- Factory interface for creating and parsing ID instances.
- IDHelper
- Helper interface for ID management in the account system.
- ImageContent
- Image message content interface.
- ImageFileContent
- InstantMessage
- Interface for plaintext instant messages (unencrypted, first stage).
- InstantMessageFactory
- Factory interface for creating and parsing InstantMessage instances.
- InstantMessageHelper
- Helper interface for instant message management.
- InviteCommand
- Group invite command interface.
- InviteGroupCommand
- JoinCommand
- Group join command interface.
- JoinGroupCommand
- ListContent
-
MemoryCache<
K, V> - Generic in-memory cache interface with memory reduction capability.
- Message
- Message transformation workflow and cryptographic operations.
- MessageExtensions
- Singleton extension class for message system operations.
- MessageFactory
- Message factory.
- MessageHandler
- Message handler interface for common message system utilities.
- Meta
- Interface for immutable metadata of network entities (users/groups).
- MetaCommand
- Meta command interface for querying/updating entity metadata.
- MetaFactory
- Factory interface for creating and parsing Meta instances.
- MetaHelper
- Helper interface for metadata (Meta) management in the account system.
- MetaType
- @enum MetaType
- MoneyContent
- Money content interface.
- NameCard
- Name card (contact) content interface.
- NameCardContent
- PageContent
- Web page message content interface.
- PrivateKey
- Interface for asymmetric private keys (part of a key pair).
- PrivateKeyFactory
- Factory interface for creating and parsing PrivateKey instances.
- PrivateKeyHelper
- Helper interface for private key management.
- PublicKey
- Interface for asymmetric public keys (part of a key pair).
- PublicKeyFactory
- Factory interface for parsing PublicKey instances from serialized data.
- PublicKeyHelper
- Helper interface for public key management.
- QuitCommand
- Group quit command interface.
- QuitGroupCommand
- QuoteContent
- Quote reply message content interface.
- ReceiptCommand
- Command message: { "type" : i2s(0x88), "sn" : 67890,
- ReliableMessage
- Interface for signed reliable messages (third/final stage).
- ReliableMessageFactory
- Factory interface for parsing ReliableMessage instances from serialized data.
- ReliableMessageHelper
- Helper interface for reliable message management.
- ResetCommand
- Group reset command interface.
- ResetGroupCommand
- SecretContent
- SecureMessage
- Interface for encrypted secure messages (second stage).
- SecureMessageFactory
- Factory interface for parsing SecureMessage instances from serialized data.
- SecureMessageHelper
- Helper interface for secure message management.
- SignKey
- Interface for private signing keys (asymmetric).
- SymmetricKey
- Interface for symmetric cryptographic keys (single key for encryption/decryption).
- SymmetricKeyFactory
- Factory interface for creating and parsing SymmetricKey instances.
- SymmetricKeyHelper
- Helper interface for symmetric key management.
- TAI
- Interface for The Additional Information (TAI) of network entities.
- TextContent
- Text message content interface.
-
ThanosCache<
K, V> - Implementation of MemoryCache with "Thanos-style" memory reduction.
- TransferContent
- Transfer money content interface. Extends MoneyContent with sender and receiver.
- TransferMoneyContent
- TransportableDataHelper
- Helper interface for processing TransportableData (TED) objects.
- TransportableFileHelper
-
Helper interface for creating/parsing
TransportableFileinstances. - VerifyKey
- Interface for public verification keys (asymmetric).
- VideoContent
- Video message content interface.
- VideoFileContent
- Visa
- User Visa document interface (user-specific authorization document).
- WebPageContent
Mixins
- CoreExtensions
- Core extensions.
- EntityExtensions
- Entity extensions.
- MessageFactoryExtensions
- Message factory extensions.
Extensions
- AddressExtension on AccountExtensions
- BundleExtension on AccountExtensions
- CommandExtension on MessageExtensions
- ContentExtension on MessageExtensions
- DocumentExtension on AccountExtensions
- EnvelopeExtension on MessageExtensions
- GeneralAccountExtension on AccountExtensions
- GeneralCommandExtension on MessageExtensions
- GeneralCryptoExtension on CryptoExtensions
- IDExtension on AccountExtensions
- InstantMessageExtension on MessageExtensions
- MemoryCacheExtension on AccountExtensions
- MessageHandlerExtension on MessageExtensions
- MetaExtension on AccountExtensions
- PrivateKeyExtension on CryptoExtensions
- PublicKeyExtension on CryptoExtensions
- ReliableMessageExtension on MessageExtensions
- SecureMessageExtension on MessageExtensions
- SymmetricKeyExtension on CryptoExtensions
- TransportableDataExtension on FormatExtensions
- TransportableFileExtension on FormatExtensions
Properties
-
Core extension manager for account system operations.
final
-
Core extension manager for cryptographic key operations.
final
-
Core extension manager for message format handling.
final
-
Core extension manager for message system operations.
final
Functions
Typedefs
- CommandCreator = Command? Function(Mapping dict)
- Builder function to create a Command from a raw map.
- ContentCreator = Content? Function(Mapping dict)
- Builder function to create a Content from a raw map.