CommandParser class
Command factory that builds command from a raw map.
Wraps a CommandCreator and verifies that the map contains both 'sn' and 'command' fields before creating the command instance.
- Implemented types
Constructors
- CommandParser(CommandCreator _builder)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parseCommand(
Mapping content) → Command? -
Parses a map object (from JSON) into a Command instance.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited