CoreExtensions mixin
Core extensions.
Registers the default account, message and command helpers into the shared extension storages, so that the whole SDK can create/parse entities and messages without extra setup.
- Mixin applications
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registerAccountHelpers(
) → void - Register the account helpers (mkm).
-
registerCommandHelpers(
) → void - Register the command helpers (cmd).
-
registerMessageHelpers(
) → void - Register the message helpers (dkd).
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited