Helper interface for secure message management.
Manages secure message factories and provides core functionality for:
- Creating secure messages (instant message + encrypted data + key bundles)
- Parsing raw secure message data into strongly-typed SecureMessage instances
SecureMessage represents an encrypted message (InstantMessage after encryption) that protects the content from unauthorized access.
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createSecureMessage(
InstantMessage iMsg, Uint8List ciphertext, Map< ID, EncryptedBundle> ? keyBundles) → SecureMessage - Creates a secure message from instant message, adding 'data' and 'keys'.
-
getSecureMessageFactory(
) → SecureMessageFactory? - Get the secure message factory.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parseSecureMessage(
Object? msg) → SecureMessage? - Parses raw secure message data into a strongly-typed SecureMessage instance.
-
setSecureMessageFactory(
SecureMessageFactory factory) → void - Set the secure message factory.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited