getDocumentID abstract method
Resolves the entity ID associated with a raw Document map.
Extracts the ID of the entity that owns the document from the raw Document data, enabling association of documents with their respective accounts.
doc is the raw Document map containing entity ID value.
Returns the resolved entity ID (null if ID cannot be extracted).
Implementation
ID? getDocumentID(Mapping doc);