Converter class final
Data Convert Utilities
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
BOOLEAN_STATES
→ Map<
String, bool> -
final
- converter ↔ DataConverter
-
getter/setter pair
- MAX_BOOLEAN_LEN ↔ int
-
getter/setter pair
Static Methods
-
getBool(
Object? value, [bool? defaultValue]) → bool? - Convert the value to a boolean, if value is None, return the default value.
-
getDateTime(
Object? value, [DateTime? defaultValue]) → DateTime? - Convert the value to a DateTime, if value is None, return the default value.
-
getDouble(
Object? value, [double? defaultValue]) → double? - Convert the value to a float number, if value is None, return the default value.
-
getInt(
Object? value, [int? defaultValue]) → int? - Convert the value to an integer, if value is None, return the default value.
-
getString(
Object? value, [String? defaultValue]) → String? - Convert the value to a string, if value is None, return the default value.