Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
decodeBundle(
Mapping encodedKeys, ID receiver, Iterable< String> ? terminals) → EncryptedBundle - Decode key data from 'message.keys'
-
encodeBundle(
EncryptedBundle bundle, ID receiver) → Map< String, Object> - Encode key data
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited