Factory interface for creating and parsing ID instances.
Provides methods to create and parse entity IDs from raw components and string representations.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createID(
{String? name, required Address address, String? terminal}) → ID - Creates an ID from explicit component values.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parseID(
String identifier) → ID? - Parses a string representation into an ID instance.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited