isBroadcast abstract method
Checks whether this is a broadcast message.
- If receiver is broadcast, return true
- If group exists and is broadcast, return true too
message is the message with sender and optional group.
Returns true if the message is a broadcast.
Implementation
bool isBroadcast(Message message);