Parses a serialized Map into a Meta instance.
meta is the serialized metadata in the Map format defined in Meta.
meta
Returns a Meta instance if parsing succeeds, null otherwise.
Meta? parseMeta(Mapping meta);