generatePrivateKey abstract method
Generate a new private key for the specified algorithm.
Creates a cryptographically secure random private key for the given algorithm.
Returns null if the algorithm is unsupported.
Implementation
PrivateKey? generatePrivateKey(String algorithm);