Helper interface for reliable message management.
Manages reliable message factories and provides core functionality for:
- Creating reliable messages (secure message + signature)
- Parsing raw reliable message data into strongly-typed ReliableMessage instances
ReliableMessage represents a signed secure message (SecureMessage after signing) that ensures message integrity and authenticity (non-repudiation).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createReliableMessage(
SecureMessage sMsg, Uint8List signature) → ReliableMessage - Creates a reliable message from secure message, adding 'signature'.
-
getReliableMessageFactory(
) → ReliableMessageFactory? - Get the reliable message factory.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parseReliableMessage(
Object? msg) → ReliableMessage? - Parses raw reliable message data into a strongly-typed ReliableMessage instance.
-
setReliableMessageFactory(
ReliableMessageFactory factory) → void - Set the reliable message factory.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited