compareToIgnoreCase abstract method
Compares this string to other ignoring case.
Returns a negative value if this is ordered before other,
a positive value if this is ordered after other,
or zero if this and other are equivalent ignoring case.
other can be a String or a Stringer (null means empty string).
Implementation
int compareToIgnoreCase(Object? other);