generateSymmetricKey abstract method
Generate a new symmetric key for the specified algorithm.
Creates a cryptographically secure random key for the given algorithm.
Returns null if the algorithm is unsupported.
Implementation
SymmetricKey? generateSymmetricKey(String algorithm);